Documentation
¶
Overview ¶
Package firehose provides a client for consuming the Bluesky firehose API stream
Index ¶
- type Firehose
- func (f *Firehose) Authenticate(email, password string) error
- func (f *Firehose) Close() error
- func (f *Firehose) ConsumeJetstream(ctx context.Context, handler func(JetstreamPost) error, ...) error
- func (f *Firehose) FetchPost(uri string) (string, error)
- func (f *Firehose) OnPost(ctx context.Context, handler func(string) error) error
- func (f *Firehose) Subscribe(ctx context.Context, handler FirehoseHandler) error
- type FirehoseHandler
- type JetstreamPost
- type Post
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Firehose ¶
type Firehose struct {
// contains filtered or unexported fields
}
Firehose represents a client connection to the Bluesky firehose
func (*Firehose) Authenticate ¶
Authenticate logs into Bluesky using email/password and stores the access token
func (*Firehose) ConsumeJetstream ¶
func (f *Firehose) ConsumeJetstream(ctx context.Context, handler func(JetstreamPost) error, errCallback ...func(error)) error
ConsumeJetstream consumes the Bluesky Jetstream API stream with the provided handler
type FirehoseHandler ¶
type FirehoseHandler interface {
HandleEvent(*atproto.SyncSubscribeRepos_Commit) error
}
FirehoseHandler defines the interface for handling firehose events
type JetstreamPost ¶
Click to show internal directories.
Click to hide internal directories.